Package: rWikiPathways
Type: Package
Title: rWikiPathways - R client library for the WikiPathways API
Version: 1.32.0
Date: 2025-10-14
Authors@R: c(person("Egon", "Willighagen", role = c("aut","cre"),
                     email = "egon.willighagen@gmail.com",
                     comment = c(ORCID = "0000-0001-7542-0286")),
             person("Alex", "Pico", role = "aut",
                     email = "alex.pico@gladstone.ucsf.edu",
                     comment = c(ORCID = "0000-0001-5706-2163"))
           )
Imports: httr, utils, XML, rjson, data.table, RCurl, dplyr, tidyr,
        readr, stringr, purrr, lubridate
Suggests: testthat, BiocStyle, knitr, rmarkdown
Encoding: UTF-8
Description: Use this package to interface with the WikiPathways API. It provides programmatic access to WikiPathways content in multiple data and image formats, including official monthly release files and convenient GMT read/write functions.
License: MIT + file LICENSE
URL: https://github.com/wikipathways/rWikiPathways
BugReports: https://github.com/wikipathways/rWikiPathways/issues
LazyLoad: yes
biocViews: Visualization, GraphAndNetwork, ThirdPartyClient, Network,
        Metabolomics
NeedsCompilation: no
VignetteBuilder: knitr
RoxygenNote: 7.2.3
git_url: https://git.bioconductor.org/packages/rWikiPathways
git_branch: RELEASE_3_23
git_last_commit: e7c3210
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
Packaged: 2026-04-29 00:21:42 UTC; biocbuild
Author: Egon Willighagen [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-7542-0286>),
  Alex Pico [aut] (ORCID: <https://orcid.org/0000-0001-5706-2163>)
Maintainer: Egon Willighagen <egon.willighagen@gmail.com>
