# Generated by roxygen2: do not edit by hand

export(downloadPathwayArchive)
export(findPathwayIDsByOrcid)
export(findPathwayIdsByLiterature)
export(findPathwayIdsByText)
export(findPathwayIdsByXref)
export(findPathwayNamesByLiterature)
export(findPathwayNamesByOrcid)
export(findPathwayNamesByText)
export(findPathwayNamesByXref)
export(findPathwayUrlsByLiterature)
export(findPathwayUrlsByOrcid)
export(findPathwayUrlsByText)
export(findPathwayUrlsByXref)
export(findPathwaysByLiterature)
export(findPathwaysByOrcid)
export(findPathwaysByText)
export(findPathwaysByXref)
export(getCounts)
export(getCurationStatus)
export(getCurationTagNames)
export(getCurationTags)
export(getEveryCurationTag)
export(getOntologyTermIds)
export(getOntologyTermNames)
export(getOntologyTerms)
export(getPathway)
export(getPathwayHistory)
export(getPathwayIdsByCommunity)
export(getPathwayIdsByCurationTag)
export(getPathwayIdsByOntologyTerm)
export(getPathwayIdsByParentOntologyTerm)
export(getPathwayInfo)
export(getPathwayNamesByCommunity)
export(getPathwayUrlsByCommunity)
export(getPathwaysByCommunity)
export(getPathwaysByCurationTag)
export(getPathwaysByOntologyTerm)
export(getPathwaysByParentOntologyTerm)
export(getRecentChanges)
export(getRecentChangesIds)
export(getRecentChangesNames)
export(getXrefList)
export(listCommunities)
export(listOrganisms)
export(listPathwayIds)
export(listPathwayNames)
export(listPathwayUrls)
export(listPathways)
export(readGMT)
export(readGMTnames)
export(readPathwayGMT)
export(wikipathwaysAPI)
export(wikipathwaysGET)
export(writeGMT)
import(dplyr)
importFrom(RCurl,getURL)
importFrom(XML,readHTMLTable)
importFrom(data.table,rbindlist)
importFrom(httr,GET)
importFrom(purrr,map_dfr)
importFrom(rjson,fromJSON)
importFrom(tidyr,separate)
importFrom(utils,URLencode)
importFrom(utils,browseURL)
importFrom(utils,download.file)
importFrom(utils,stack)
importFrom(utils,write.table)
