% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/findPathwaysByText.R
\name{findPathwaysByText}
\alias{findPathwaysByText}
\title{Find Pathways By Text}
\usage{
findPathwaysByText(query = NULL, field = NULL)
}
\arguments{
\item{query}{A \code{character} string to search for, e.g., "cancer". Case 
insensitive.}

\item{field}{Optional \code{character} string to restrict search to a single
field, e.g., id, name, description, species, revision, authors,
datanodes, annotations, or citedIn.}
}
\value{
A \code{dataframe} of pathway attributes including the matching
attributes
}
\description{
Retrieve pathways matching the query text.
}
\details{
Searches id, name, description, species, revision date, authors,
datanode labels, ontology annotations, and citedIn (e.g., PMCIDs).
}
\examples{
{
findPathwaysByText('cancer')
findPathwaysByText('cancer','name')
}
}
